# gff-io

GFF reader/writer.

## Install

```bash
pip install gff-io
```

## Author

* [Danilo Horta](https://github.com/horta)

## License

This project is licensed under the [MIT License](https://raw.githubusercontent.com/EBI-Metagenomics/gff-io/master/LICENSE.md).
